<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+111"/>
      <source>Reverse Engineering</source>
      <translation>Ters Mühendislik</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Yaklaşık düzlem ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Bir düzleme yaklaşık</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-62"/>
      <source>Reverse Engineering</source>
      <translation>Ters Mühendislik</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate surface...</source>
      <translation>Yaklaşık yüzey ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-Spline surface</source>
      <translation>Yaklaşık olarak bir B-Spline yüzeyi hesaplamak</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>Ters Mühendislik</translation>
    </message>
  </context>
</TS>
